<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu" sourcelanguage="en_US">
<context>
    <name>Application</name>
    <message>
        <location filename="../src/application.cpp" line="427"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/application.cpp" line="104"/>
        <location filename="../src/application.cpp" line="150"/>
        <source>Draw</source>
        <translation>Rajzoló</translation>
    </message>
    <message>
        <location filename="../src/application.cpp" line="426"/>
        <source>You can import up to 30 pictures, please try again!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BlurWidget</name>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/blurwidget.cpp" line="100"/>
        <source>Type</source>
        <translation>Típus</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/blurwidget.cpp" line="110"/>
        <source>Blur</source>
        <translation>Elmosás</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/blurwidget.cpp" line="123"/>
        <source>Mosaic</source>
        <translation>Mozaik</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/blurwidget.cpp" line="146"/>
        <source>Width</source>
        <translation>Szélesség</translation>
    </message>
</context>
<context>
    <name>CAbstractProcessDialog</name>
    <message>
        <location filename="../src/widgets/dialog/cprogressdialog.cpp" line="105"/>
        <source>Export</source>
        <translation>Exportálás</translation>
    </message>
</context>
<context>
    <name>CAlphaControlWidget</name>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/calphacontrolwidget.cpp" line="65"/>
        <source>Alpha</source>
        <translation>Átlátszóság</translation>
    </message>
</context>
<context>
    <name>CCutDialog</name>
    <message>
        <location filename="../src/widgets/dialog/ccutdialog.cpp" line="41"/>
        <source>Discard</source>
        <translation>Elvetés</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/ccutdialog.cpp" line="42"/>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/ccutdialog.cpp" line="47"/>
        <source>Do you want to save the cropped image?</source>
        <translation>El akarja menteni a kivágott képet?</translation>
    </message>
</context>
<context>
    <name>CCutTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/ccuttool.cpp" line="90"/>
        <source>Crop (C)</source>
        <translation>Vágás (C)</translation>
    </message>
</context>
<context>
    <name>CCutWidget</name>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="230"/>
        <source>Dimensions</source>
        <translation>Méretek</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="245"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="295"/>
        <source>Aspect ratio</source>
        <translation>Oldalarány</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="336"/>
        <source>Free</source>
        <translation>Szabad</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="343"/>
        <source>Original</source>
        <translation>Eredeti</translation>
    </message>
</context>
<context>
    <name>CEllipseTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cellipsetool.cpp" line="57"/>
        <source>Ellipse (O)</source>
        <translation>Ellipszis (O)</translation>
    </message>
</context>
<context>
    <name>CEraserTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cerasertool.cpp" line="98"/>
        <source>Eraser (E)</source>
        <translation>Radír (E)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cerasertool.cpp" line="113"/>
        <source>Width</source>
        <translation>Szélesség</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="548"/>
        <source>Percentage</source>
        <translation>Százalék</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="562"/>
        <source>Pixels</source>
        <translation>Képpont</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="564"/>
        <source>Dimensions:</source>
        <translation>Méretek:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="586"/>
        <source>Lock aspect ratio</source>
        <translation>Méretarány rögzítése</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="595"/>
        <source>W:</source>
        <translation>SZ:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="600"/>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="611"/>
        <source>pixels</source>
        <translation>képpont</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="605"/>
        <source>H:</source>
        <translation>M:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="868"/>
        <source>It supports up to 10,000 pixels</source>
        <translation>Legfeljebb 10.000 képpontot támogatott</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="98"/>
        <source>Unnamed</source>
        <translation>Névtelen</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="173"/>
        <source>Export</source>
        <translation>Exportálás</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="186"/>
        <source>Pictures</source>
        <translation>Képek</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="188"/>
        <source>Documents</source>
        <translation>Dokumentumok</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="189"/>
        <source>Downloads</source>
        <translation>Letöltések</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="190"/>
        <source>Desktop</source>
        <translation>Asztal</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="191"/>
        <source>Videos</source>
        <translation>Videók</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="192"/>
        <source>Music</source>
        <translation>Zenék</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="193"/>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="207"/>
        <source>Select other directories</source>
        <translation>Válasszon más könyvtárakat</translation>
    </message>
    <message>
        <source>jpg</source>
        <translation type="vanished">jpg</translation>
    </message>
    <message>
        <source>png</source>
        <translation type="vanished">png</translation>
    </message>
    <message>
        <source>bmp</source>
        <translation type="vanished">bmp</translation>
    </message>
    <message>
        <source>tif</source>
        <translation type="vanished">tif</translation>
    </message>
    <message>
        <source>pdf</source>
        <translation type="vanished">pdf</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="265"/>
        <source>Name:</source>
        <translation>Név:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="266"/>
        <source>Save to:</source>
        <translation>Mentés ide:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="268"/>
        <source>Format:</source>
        <translation>Formátum:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="269"/>
        <source>Quality:</source>
        <translation>Minőség:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="275"/>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="281"/>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="407"/>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="276"/>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="282"/>
        <source>Replace</source>
        <translation>Csere</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="406"/>
        <source>This file will be hidden if the file name starts with a dot (.). Do you want to hide it?</source>
        <translation>Ez a fájl el lesz rejtve, ha a fájl neve ponttal (.) kezdődik. El kívánja rejteni?</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="407"/>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="421"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="423"/>
        <source>The file name is too long</source>
        <translation>A fájlnév túl hosszú</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="506"/>
        <source>%1 
 already exists, do you want to replace it?</source>
        <translation>%1 már létezik, kívánja felülírni?</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="866"/>
        <source>At least one pixel please</source>
        <translation>Legalább egy képpont</translation>
    </message>
</context>
<context>
    <name>CLineTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/clinetool.cpp" line="58"/>
        <source>Line (L)</source>
        <translation>Vonal (L)</translation>
    </message>
</context>
<context>
    <name>CPenTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="79"/>
        <source>Pencil (P)</source>
        <translation>Ceruza (P)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="96"/>
        <source>Start</source>
        <translation>Eleje</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="124"/>
        <source>End</source>
        <translation>Vége</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="167"/>
        <source>Watercolor</source>
        <translation>Vízfestmény</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="168"/>
        <source>Calligraphy pen</source>
        <translation>Kalligráfiai toll</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="169"/>
        <source>Crayon</source>
        <translation>Zsírkréta</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="514"/>
        <source>Style</source>
        <translation>Stílus</translation>
    </message>
</context>
<context>
    <name>CPictureTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="87"/>
        <source>Import (I)</source>
        <translation>Importálás (I)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="114"/>
        <source>Rotate 90° CCW</source>
        <translation>Elforgatás 90°-kal balra</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="132"/>
        <source>Rotate 90° CW</source>
        <translation>Elforgatás 90°-kal jobbra</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="149"/>
        <source>Flip horizontally</source>
        <translation>Vízszintes tükrözés</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="169"/>
        <source>Flip vertically</source>
        <translation>Függőleges tükrözés</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="188"/>
        <source>Auto fit</source>
        <translation>Automatikus illesztés</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="232"/>
        <source>Import Picture</source>
        <translation>Kép importálása</translation>
    </message>
</context>
<context>
    <name>CPolygonTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cpolygontool.cpp" line="69"/>
        <source>Polygon (H)</source>
        <translation>Sokszög (H)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpolygontool.cpp" line="86"/>
        <source>Sides</source>
        <translation>Oldalak</translation>
    </message>
</context>
<context>
    <name>CPolygonalStarTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cpolygonalstartool.cpp" line="49"/>
        <source>Star (F)</source>
        <translation>Csillag (F)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpolygonalstartool.cpp" line="90"/>
        <source>Points</source>
        <translation>Pontok</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpolygonalstartool.cpp" line="97"/>
        <source>Radius</source>
        <translation>Sugár</translation>
    </message>
</context>
<context>
    <name>CRectTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/crecttool.cpp" line="68"/>
        <source>Rectangle (R)</source>
        <translation>Téglalap (R)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/crecttool.cpp" line="136"/>
        <source>Fill</source>
        <translation>Kitöltés</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/crecttool.cpp" line="142"/>
        <source>Corner Radius</source>
        <translation>Sarkok sugara</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/crecttool.cpp" line="273"/>
        <source>Width</source>
        <translation>Szélesség</translation>
    </message>
</context>
<context>
    <name>CSelectTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cselecttool.cpp" line="90"/>
        <source>Select (V)</source>
        <translation>Kijelölés (V)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cselecttool.cpp" line="124"/>
        <source>Unnamed</source>
        <translation>Névtelen</translation>
    </message>
</context>
<context>
    <name>CTextTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="68"/>
        <source>Color</source>
        <translation>Szín</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="99"/>
        <source>Text (T)</source>
        <translation>Szöveg (T)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="229"/>
        <source>Input text here</source>
        <translation>Írja ide a szöveget</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="328"/>
        <source>Weight</source>
        <translation>Súly</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="344"/>
        <source>Font</source>
        <translation>Betűtípus</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="469"/>
        <source>Size</source>
        <translation>Méret</translation>
    </message>
</context>
<context>
    <name>CTriangleTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/ctriangletool.cpp" line="62"/>
        <source>Triangle (S)</source>
        <translation>Háromszög (S)</translation>
    </message>
</context>
<context>
    <name>ColorPanel</name>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/colorpanel.cpp" line="175"/>
        <source>Color</source>
        <translation>Szín</translation>
    </message>
</context>
<context>
    <name>DrawAttribution::CGroupButtonWgt</name>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/cattributeitemwidget.cpp" line="487"/>
        <location filename="../src/frame/AttributesWidgets/private/cattributeitemwidget.cpp" line="499"/>
        <source>Group</source>
        <translation>Csoportosítás</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/cattributeitemwidget.cpp" line="490"/>
        <location filename="../src/frame/AttributesWidgets/private/cattributeitemwidget.cpp" line="507"/>
        <source>Ungroup</source>
        <translation>Csoportosítás bontása</translation>
    </message>
</context>
<context>
    <name>DrawDialog</name>
    <message>
        <location filename="../src/widgets/dialog/drawdialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/drawdialog.cpp" line="43"/>
        <source>Discard</source>
        <translation>Elvetés</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/drawdialog.cpp" line="44"/>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/drawdialog.cpp" line="47"/>
        <source>Save the current contents?</source>
        <translation>Elmenti a jelenlegi tartalmat?</translation>
    </message>
</context>
<context>
    <name>FileHander</name>
    <message>
        <location filename="../src/service/filehander.cpp" line="596"/>
        <source>Opening...</source>
        <translation>Megnyitás...</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="623"/>
        <source>Saving...</source>
        <translation>Mentés...</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="650"/>
        <source>Damaged file, unable to open it</source>
        <translation>Sérült fájl, nem sikerült megnyitni</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="705"/>
        <location filename="../src/service/filehander.cpp" line="828"/>
        <source>The file does not exist</source>
        <translation>A fájl nem létezik</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="724"/>
        <source>Unable to open &quot;%1&quot;, unsupported file format</source>
        <translation>A &quot;%1&quot; megnyitása nem lehetséges, nem támogatott fájlformátum</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="749"/>
        <source>The file name must not contain \/:*?&quot;&lt;&gt;|</source>
        <translation>A fájlnév nem tartalmazhatja a \ /: *? &quot;&lt;&gt; | karaktereket</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="839"/>
        <source>Unable to open the write-only file &quot;%1&quot;</source>
        <translation>A &quot;%1&quot; csak írható fájl, megnyitása nem lehetséges</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="852"/>
        <source>This file is read-only, please save with another name</source>
        <translation>Ez a fájl csak olvasható, kérjük mentse más néven</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="860"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>Nincs jogosultsága a fájlok ezen helyre történő mentésére. Kérjük módosítsa az útvonalat, és próbálja újra</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="881"/>
        <source>The file is incompatible with the old app, please install the latest version</source>
        <translation>A fájl nem kompatibilis a régebbi alkalmazással, ezért kérjük telepítse a legújabb verziót</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="899"/>
        <source>Unable to open the broken file &quot;%1&quot;</source>
        <translation>Nem sikerült megnyitni a &quot;%1&quot; sérült fájlt</translation>
    </message>
</context>
<context>
    <name>FileSelectDialog</name>
    <message>
        <location filename="../src/frame/cmultiptabbarwidget.cpp" line="202"/>
        <source>The file name must not contain \/:*?&quot;&lt;&gt;|</source>
        <translation>A fájlnév nem tartalmazhatja a \ /: *? &quot;&lt;&gt; | karaktereket</translation>
    </message>
    <message>
        <location filename="../src/frame/cmultiptabbarwidget.cpp" line="204"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/frame/cmultiptabbarwidget.cpp" line="231"/>
        <source>Cannot save it as %1, since the file in that name is open now.
Please save it in another name or close that file and try again.</source>
        <translation>Nem menthető %1 néven, mivel az ilyen nevű fájl most nyitva van.
Kérjük, mentse más néven, vagy zárja be a fájlt, és próbálja újra.</translation>
    </message>
</context>
<context>
    <name>IBlurTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cmasicotool.cpp" line="148"/>
        <source>Blur (B)</source>
        <translation>Elmosódás (B)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/frame/mainwindow.cpp" line="105"/>
        <source>Draw</source>
        <translation>Rajzoló</translation>
    </message>
    <message>
        <location filename="../src/frame/mainwindow.cpp" line="200"/>
        <source>Export successful</source>
        <translation>Az exportálás sikeres</translation>
    </message>
    <message>
        <location filename="../src/frame/mainwindow.cpp" line="200"/>
        <source>Export failed</source>
        <translation>Az exportálás sikertelen</translation>
    </message>
    <message>
        <location filename="../src/frame/mainwindow.cpp" line="228"/>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
</context>
<context>
    <name>PageContext</name>
    <message>
        <location filename="../src/drawshape/cdrawparamsigleton.cpp" line="66"/>
        <source>Unnamed</source>
        <translation>Névtelen</translation>
    </message>
</context>
<context>
    <name>PageView</name>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="322"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="666"/>
        <source>Layer</source>
        <translation>Réteg</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="324"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="683"/>
        <source>Cut</source>
        <translation>Kivágás</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="329"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="684"/>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="334"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="685"/>
        <source>Paste</source>
        <translation>Beillesztés</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="341"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="686"/>
        <source>Select All</source>
        <translation>Összes kijelölése</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="348"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="692"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="354"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="687"/>
        <source>Undo</source>
        <translation>Visszavonás</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="363"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="688"/>
        <source>Redo</source>
        <translation>Visszavonás újra</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="372"/>
        <source>Raise Layer</source>
        <translation>Réteg emelése</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="377"/>
        <source>Lower Layer</source>
        <translation>Réteg süllyesztése</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="382"/>
        <source>Layer to Top</source>
        <translation>Réteg legfelülre helyezése</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="387"/>
        <source>Layer to Bottom</source>
        <translation>Réteg legalulra helyezése</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="416"/>
        <source>Group</source>
        <translation>Csoportosítás</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="421"/>
        <source>Ungroup</source>
        <translation type="unfinished">Csoportosítás bontása</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="427"/>
        <source>Align</source>
        <translation>Igazítás</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="430"/>
        <source>Align left</source>
        <translation>Igazítás balra</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="435"/>
        <source>Horizontal centers</source>
        <translation>Vízszintesen középre</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="440"/>
        <source>Align right</source>
        <translation>Igazítás jobbra</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="445"/>
        <source>Align top</source>
        <translation>Igazítás fel</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="450"/>
        <source>Vertical centers</source>
        <translation>Függőlegesen középre</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="455"/>
        <source>Align bottom</source>
        <translation>Igazítás le</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="460"/>
        <source>Distribute horizontal space</source>
        <translation>Vízszintes hely felosztása</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="462"/>
        <source>Distribute vertical space</source>
        <translation>Függőleges hely felosztása</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="689"/>
        <source>Text Align Left</source>
        <translation>Szöveg balra igazítása</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="690"/>
        <source>Text Align Right</source>
        <translation>Szöveg jobbra igazítása</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="691"/>
        <source>Text Align Center</source>
        <translation>Szöveg középre igazítása</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/frame/mainwindow.cpp" line="75"/>
        <location filename="../src/frame/cviewmanagement.cpp" line="202"/>
        <source>File not saved</source>
        <translation>A fájl nincs elmentve</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="355"/>
        <source>Source Han Sans CN</source>
        <translation>Forrás Han Sans CN</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/crecttool.cpp" line="84"/>
        <source>Stroke</source>
        <translation>Keret</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="103"/>
        <source>The blur effect will be lost as the file is in old version. Proceed to open it?</source>
        <translation>Az elmosódás elvész, mivel a fájl régi verziójú. Folytatja a megnyitását?</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="104"/>
        <location filename="../src/service/filehander.cpp" line="129"/>
        <location filename="../src/service/filehander.cpp" line="203"/>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="104"/>
        <location filename="../src/service/filehander.cpp" line="129"/>
        <location filename="../src/service/filehander.cpp" line="203"/>
        <location filename="../src/frame/ccentralwidget.cpp" line="757"/>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="385"/>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="128"/>
        <location filename="../src/service/filehander.cpp" line="202"/>
        <source>The file is in an older version, and the properties of elements will be changed. Proceed to open it?</source>
        <translation>Az adott fájl egy régebbi verziójú állomány, és az elemek tulajdonságai megváltoznak. Folytatja a fájl megnyitását?</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="462"/>
        <source>Unable to save. There is not enough disk space.</source>
        <translation>A mentés nem lehetséges. Nincs elég lemezterület.</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="287"/>
        <source>Unnamed</source>
        <translation>Névtelen</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="300"/>
        <source>The dimensions of %1 exceed the canvas. How to display it?</source>
        <translation>A %1 méretei meghaladják a vásznat. Hogyan kívánja megjeleníteni?</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="289"/>
        <location filename="../src/frame/ccentralwidget.cpp" line="301"/>
        <source>Keep original size</source>
        <translation>Eredeti méret megtartása</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="289"/>
        <location filename="../src/frame/ccentralwidget.cpp" line="301"/>
        <source>Auto fit</source>
        <translation>Automatikus illesztés</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="296"/>
        <source>Apply to all</source>
        <translation>Alkalmazás az összesre</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="755"/>
        <source>%1 has been modified in other programs. Do you want to reload it?</source>
        <translation>A %1 módosult más programokban. Szeretné újratölteni?</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="756"/>
        <source>Reload</source>
        <translation>Újratöltés</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="1289"/>
        <location filename="../src/frame/ccentralwidget.cpp" line="1691"/>
        <source>Import failed: no more than 10,000 pixels please</source>
        <translation>Az importálás sikertelen: legfeljebb 10 000 képpont</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/dialog.h" line="45"/>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="374"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/widgets/progresslayout.cpp" line="37"/>
        <location filename="../src/frame/ccentralwidget.cpp" line="1224"/>
        <source>Opening...</source>
        <translation>Megnyitás...</translation>
    </message>
    <message>
        <location filename="../src/widgets/progresslayout.cpp" line="158"/>
        <source>%1/%2</source>
        <translation>%1/%2</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="vanished">Összes kijelölése</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="vanished">Kivágás</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation type="vanished">Visszavonás</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Másolás</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="vanished">Beillesztés</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Törlés</translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="vanished">Csoportosítás</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation type="vanished">Csoportosítás bontása</translation>
    </message>
    <message>
        <source>pdf</source>
        <translation type="vanished">pdf</translation>
    </message>
    <message>
        <location filename="../src/application.cpp" line="72"/>
        <location filename="../src/application.cpp" line="80"/>
        <source>DDF Drawings</source>
        <translation>DDF Drawings</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="34"/>
        <source>Files</source>
        <translation>Fájlok</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="35"/>
        <source>Drawing</source>
        <translation>Rajzolás</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="36"/>
        <source>Shapes/Images</source>
        <translation>Formák/Képek</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="37"/>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="38"/>
        <source>Align</source>
        <translation>Igazítás</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="42"/>
        <source>New</source>
        <translation>Új</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="43"/>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="44"/>
        <source>Export</source>
        <translation>Exportálás</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="45"/>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="46"/>
        <source>Save as</source>
        <translation>Mentés másként</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="47"/>
        <source>Print</source>
        <translation>Nyomtatás</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="50"/>
        <source>Select</source>
        <translation>Kijelölés</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="51"/>
        <source>Import</source>
        <translation>Importálás</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="52"/>
        <source>Rectangle</source>
        <translation>Téglalap</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="53"/>
        <source>Ellipse</source>
        <translation>Ellipszis</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="54"/>
        <source>Triangle</source>
        <translation>Háromszög</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="55"/>
        <source>Star</source>
        <translation>Csillag</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="56"/>
        <source>Polygon</source>
        <translation>Sokszög</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="57"/>
        <source>Line</source>
        <translation>Vonal</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="59"/>
        <source>Pencil</source>
        <translation>Ceruza</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="58"/>
        <source>Text</source>
        <translation>Szöveg</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="60"/>
        <source>Eraser</source>
        <translation>Radír</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="61"/>
        <source>Blur</source>
        <translation>Elhomályosítás</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="62"/>
        <source>Crop</source>
        <translation>Levágás</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="63"/>
        <source>Expand canvas</source>
        <translation>Vászon kiterjesztése</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="64"/>
        <source>Shrink canvas</source>
        <translation>Vászon zsugorítása</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="69"/>
        <source>Cut</source>
        <translation>Kivágás</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="70"/>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="71"/>
        <source>Paste</source>
        <translation>Beillesztés</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="72"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="73"/>
        <source>Undo</source>
        <translation>Visszavonás</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="74"/>
        <source>Redo</source>
        <translation>Visszavonás újra</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="75"/>
        <source>Group</source>
        <translation>Csoportosítás</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="76"/>
        <source>Ungroup</source>
        <translation>Csoportosítás bontása</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="77"/>
        <source>Raise Layer</source>
        <translation>Réteg emelése</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="78"/>
        <source>Lower Layer</source>
        <translation>Réteg süllyesztése</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="79"/>
        <source>Layer to Top</source>
        <translation>Réteg legfelülre helyezése</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="80"/>
        <source>Layer to Bottom</source>
        <translation>Réteg legalulra helyezése</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="84"/>
        <source>Help</source>
        <translation>Segítség</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="85"/>
        <source>Display shortcuts</source>
        <translation>Gyorsbillentyűk megjelenítése</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="87"/>
        <source>Align left</source>
        <translation>Igazítás balra</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="88"/>
        <source>Align right</source>
        <translation>Igazítás jobbra</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="89"/>
        <source>Horizontal centers</source>
        <translation>Vízszintesen középre</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="90"/>
        <source>Align top</source>
        <translation>Igazítás fel</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="91"/>
        <source>Align bottom</source>
        <translation>Igazítás le</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="92"/>
        <source>Vertical centers</source>
        <translation>Függőlegesen középre</translation>
    </message>
</context>
<context>
    <name>TabBarWgt</name>
    <message>
        <location filename="../src/frame/cmultiptabbarwidget.cpp" line="120"/>
        <source>Close tab</source>
        <translation>Fül bezárása</translation>
    </message>
    <message>
        <location filename="../src/frame/cmultiptabbarwidget.cpp" line="125"/>
        <source>Close other tabs</source>
        <translation>Egyéb fülek bezárása</translation>
    </message>
</context>
<context>
    <name>TopTilte</name>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="173"/>
        <source>New</source>
        <translation>Új</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="178"/>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="199"/>
        <location filename="../src/frame/toptoolbar.cpp" line="225"/>
        <source>Export</source>
        <translation>Exportálás</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="189"/>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="194"/>
        <source>Save as</source>
        <translation>Mentés másként</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="209"/>
        <source>Print</source>
        <translation>Nyomtatás</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="242"/>
        <source>Draw</source>
        <translation>Rajzoló</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="245"/>
        <source>Draw is a lightweight drawing tool for users to freely draw and simply edit images. </source>
        <translation>A Deepin® Rajzoló egy pehelykönnyű rajzalkalmazás szabadkézi rajzok készítéséhez és képek szerkesztéséhez.</translation>
    </message>
</context>
</TS>
